WebLogo 3 - Tests
Author: Gavin E. Crooks

# WebLogo 3: Tests | · about · create · examples · manual ·
Various tests of the WebLogo webapp. Relative Entropy Test The entropy should be 2 bits, 1 bit, 0 bits (The small sample correction should be turned off.) Title And Labels Test Replace and display x-label, y-label and title. Same, but do not show axes Format Test Ensure that this logo can be created in each of the available formats Format: Test Alphabetic Order Each character in each stack has the same entropy. The letters should be alphabetized, top down. (NA) (AA) One Single Column Should not die just because there is only 1 stack. Small Sample Correction Test The samples per column decrease from 32 (left) to 1 (right). Before the small sample correction the relative entropy of each stack is 2 bits. Test Graceful Failure Each of these tests should result in a polite and informative error message. Logo Sizes Same sequences, three different sizes. Size: Transfac test